import json

from pkgme.run_script import run_script, ScriptMissing


class ProjectInfo(object):

    def get_all(self, keys):
        raise NotImplementedError(self.get_all)


class DictInfo(ProjectInfo):

    def __init__(self, info):
        self.info = info

    def get_all(self, keys):
        values = {}
        for key in keys:
            if key in self.info:
                values[key] = self.info[key]
        return values


class _ExternalHelpersInfo(ProjectInfo):

    def __init__(self, basepath, cwd):
        self.basepath = basepath
        self.cwd = cwd


class SingleExternalHelperInfo(_ExternalHelpersInfo):

    INFO_SCRIPT_NAME = "all_info"

    def get_all(self, keys):
        out = run_script(
            self.basepath, self.INFO_SCRIPT_NAME, self.cwd,
            to_write=json.dumps(keys))
        return json.loads(out)


class MultipleExternalHelpersInfo(_ExternalHelpersInfo):

    def _get(self, key):
        try:
            out = run_script(self.basepath, key, self.cwd)
        except ScriptMissing:
            return None
        return out.rstrip("\n")

    def get_all(self, keys):
        values = {}
        for key in keys:
            values[key] = self._get(key)
        return values
