import os

from fixtures import TestWithFixtures
from testtools import TestCase

from pkgme import write_packaging
from pkgme.backend import (
    reset_default_loader_factory,
    set_default_loader_factory,
    StaticBackend,
    StaticLoader,
    )
from pkgme.info_elements import (
    Architecture,
    Description,
    Maintainer,
    PackageName,
    Version,
    )
from pkgme.package_files import Control, DEBIAN_DIR
from pkgme.project_info import DictInfo
from pkgme.testing import (
    ControlSourceStanzaHasField,
    TempdirFixture,
    )


class WritePackagingTests(TestCase, TestWithFixtures):

    def test_write_packaging(self):
        name = self.getUniqueString()
        info = DictInfo(
            {
                PackageName.name: name,
                Maintainer.name: self.getUniqueString(),
                Architecture.name: "all",
                Description.name: self.getUniqueString(),
                Version.name: "1",
            })
        tempdir = self.useFixture(TempdirFixture())
        backend = StaticBackend(
            self.getUniqueString(), 10, info, expected_path=tempdir.path)
        loader = StaticLoader([backend])
        def get_loader():
            return loader
        self.addCleanup(reset_default_loader_factory)
        set_default_loader_factory(get_loader)
        write_packaging(tempdir.path)
        control_path = os.path.join(
            tempdir.path, DEBIAN_DIR, Control.filename)
        with open(control_path) as f:
            control_contents = f.read()
        self.assertThat(
            control_contents,
            ControlSourceStanzaHasField("Source", name))
